pub struct Ref {
pub name: String,
}Expand description
A server refspec, used by both batch and locking requests for auth schemes that take the ref into account (added in LFS v2.4).
See docs/api/batch.md  “Ref Property”.
Fields
name: StringImplementations